@@ -264,14 +264,12 @@ void session_set_timeout(Session *session, guint interval)
 
 	session->timeout_interval = interval;
 	if (interval > 0) {
-#if GLIB_CHECK_VERSION(2,14,0)
 		if (interval % 1000 == 0)
 			session->timeout_tag =
 				g_timeout_add_seconds(interval/1000, session_timeout_cb, session);
 		else
-#endif
-		session->timeout_tag =
-			g_timeout_add(interval, session_timeout_cb, session);
+			session->timeout_tag =
+				g_timeout_add(interval, session_timeout_cb, session);
 	} else
 		session->timeout_tag = 0;
 }
@@ -376,11 +374,12 @@ gint session_start_tls(Session *session)
 	nb_mode = sock_is_nonblocking_mode(session->sock);
 
 	session->sock->ssl_cert_auto_accept = session->ssl_cert_auto_accept;
+	session->sock->gnutls_priority = session->gnutls_priority;
 
 	if (nb_mode)
 		sock_set_nonblocking_mode(session->sock, FALSE);
 
-	if (!ssl_init_socket_with_method(session->sock, SSL_METHOD_TLSv1)) {
+	if (!ssl_init_socket(session->sock)) {
 		g_warning("couldn't start TLS session.\n");
 		if (nb_mode)
 			sock_set_nonblocking_mode(session->sock, session->nonblocking);
@@ -892,11 +891,5 @@ void session_register_ping(Session *session, gboolean (*ping_cb)(gpointer data))
 	session->ping_tag = -1;
 
 	if (ping_cb != NULL)
-#if GLIB_CHECK_VERSION(2,14,0)
-		session->ping_tag =
-			g_timeout_add_seconds(60, ping_cb, session);
-#else
-		session->ping_tag =
-			g_timeout_add(60*1000, ping_cb, session);
-#endif
+		session->ping_tag = g_timeout_add_seconds(60, ping_cb, session);
 }
