@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2014 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,44 +48,19 @@
 #  include <wchar.h>
 #endif
 
+/* The Hurd doesn't have this limit */
+#ifndef PATH_MAX
+  #define PATH_MAX 4196
+#endif
+
 #ifdef G_OS_WIN32
 
 #define fsync _commit
 
-#if GLIB_CHECK_VERSION (2, 13, 2)
 #define pipe(phandles)  _pipe (phandles, 4096, _O_BINARY)
 #endif
-#endif
 /* Wrappers for C library function that take pathname arguments. */
-#if GLIB_CHECK_VERSION(2, 6, 0)
 #  include <glib/gstdio.h>
-#else
-
-#define g_open		open
-#define g_rename	rename
-#define g_mkdir		mkdir
-#define g_stat		stat
-#define g_lstat		lstat
-#define g_unlink	unlink
-#define g_remove	remove
-#define g_rmdir		rmdir
-#define g_fopen		fopen
-#define g_freopen	freopen
-
-#endif /* GLIB_CHECK_VERSION */
-
-#if !GLIB_CHECK_VERSION(2, 7, 0)
-
-#ifdef G_OS_UNIX
-#define g_chdir		chdir
-#define g_chmod		chmod
-#else
-gint g_chdir	(const gchar	*path);
-gint g_chmod	(const gchar	*path,
-		 gint		 mode);
-#endif /* G_OS_UNIX */
-
-#endif /* !GLIB_CHECK_VERSION */
 
 /* why is this sometimes undefined !? */
 #ifndef G_MAXOFFSET
@@ -247,6 +222,13 @@ G_STMT_END
 	} 								\
 } G_STMT_END
 
+#ifndef MIN
+	#define MIN(a, b) ((a) < (b) ? (a) : (b))
+#endif
+#ifndef MAX
+	#define MAX(a, b) ((a) > (b) ? (a) : (b))
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
