@@ -857,6 +857,8 @@ static void folderview_select_node(FolderView *folderview, GtkCMCTreeNode *node)
 		return;
 	}
 
+	gtkut_ctree_expand_parent_all(ctree, node);
+
 	folderview->open_folder = TRUE;
 	gtkut_ctree_set_focus_row(ctree, node);
 	gtk_cmctree_select(ctree, node);
@@ -866,8 +868,6 @@ static void folderview_select_node(FolderView *folderview, GtkCMCTreeNode *node)
 		summary_grab_focus(folderview->summaryview);
 	else
 		gtk_widget_grab_focus(folderview->ctree);
-
-	gtkut_ctree_expand_parent_all(ctree, node);
 }
 
 void folderview_unselect(FolderView *folderview)
@@ -1189,6 +1189,43 @@ void folderview_check_new_all(void)
 	inc_unlock();
 }
 
+static gboolean folderview_have_children_sub(FolderView *folderview,
+					     FolderItem *item,
+					     gboolean in_sub)
+{
+	GNode *node = NULL;
+	
+	if (!item || !item->folder || !item->folder->node)
+		return FALSE;
+		
+	node = item->folder->node;
+	
+	node = g_node_find(node, G_PRE_ORDER, G_TRAVERSE_ALL, item);
+	node = node->children;
+
+	if (in_sub && item->total_msgs > 0) {
+		return TRUE;
+	}
+
+	while (node != NULL) {
+		if (node && node->data) {
+			FolderItem *next_item = (FolderItem*) node->data;
+			node = node->next;
+			if (folderview_have_children_sub(folderview, 
+							 next_item, TRUE))
+				return TRUE;
+		}
+	}
+
+	return FALSE;
+}
+
+static gboolean folderview_have_children(FolderView *folderview,
+					 FolderItem *item)
+{
+	return folderview_have_children_sub(folderview, item, FALSE);
+}
+
 static gboolean folderview_have_new_children_sub(FolderView *folderview,
 						 FolderItem *item,
 						 gboolean in_sub)
@@ -1540,6 +1577,10 @@ static void folderview_update_node(FolderView *folderview, GtkCMCTreeNode *node)
 				break;
 			}
 		}
+		if (!GTK_CMCTREE_ROW(node)->expanded &&
+		    use_bold == FALSE &&
+		    folderview_have_children(folderview, item))
+			use_bold = use_color = TRUE;
 		procmsg_msg_list_free(list);
 	} else {
 		/* if unread messages exist, print with bold font */
