@@ -209,7 +209,6 @@ static gchar *quicksearch_get_text(QuickSearch * quicksearch)
 {
 	gchar *search_string = gtk_editable_get_chars(GTK_EDITABLE(gtk_bin_get_child(GTK_BIN((quicksearch->search_string_entry)))), 0, -1);
 
-	g_strstrip(search_string);
 	return search_string;
 }
 
@@ -464,7 +463,8 @@ static gchar *search_descr_strings[] = {
 	"f S",	 N_("messages originating from user S"),
 	"F",	 N_("forwarded messages"),
 	"ha",	 N_("messages which have attachments"),
-	"h S",	 N_("messages which contain header S"),
+	"h S",	 N_("messages which contain S in any header name or value"),
+	"H S",	 N_("messages which contain S in the value of any header"),
 	"i S",	 N_("messages which contain S in Message-ID header"),
 	"I S",	 N_("messages which contain S in In-Reply-To header"),
 	"k #",	 N_("messages which are marked with color #"),
