@@ -458,9 +458,6 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	mimeview->icon_mainbox  = icon_mainbox;
 	mimeview->icon_count    = 0;
 	mimeview->mainwin       = mainwin;
-#if !(GTK_CHECK_VERSION(2,12,0))
-	mimeview->tooltips      = tips;
-#endif
 	mimeview->mime_toggle   = mime_toggle;
 	mimeview->siginfoview	= siginfoview;
 	mimeview->scrollbutton  = scrollbutton;
@@ -1462,7 +1459,8 @@ static void mimeview_selected(GtkTreeSelection *selection, MimeView *mimeview)
 		}
 	}
 
-	if (mimeview->siginfo && privacy_auto_check_signatures(mimeview->siginfo)) {
+	if (mimeview->siginfo && privacy_auto_check_signatures(mimeview->siginfo)
+	&&  privacy_mimeinfo_get_sig_status(mimeview->siginfo) == SIGNATURE_UNCHECKED) {
 		mimeview_check_signature(mimeview);
 	}
 }
@@ -2413,9 +2411,6 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 #ifdef GENERIC_UMPC
 	GtkRequisition r;
 #endif
-#if !(GTK_CHECK_VERSION(2,12,0))
-	GtkTooltips *tips = mimeview->tooltips;
-#endif
 	
 	if (!prefs_common.show_inline_attachments && mimeinfo->id)
 		return;
