@@ -70,6 +70,7 @@ static gboolean libravatar_header_update_hook(gpointer source, gpointer data)
 
 		debug_print("libravatar added '%s'\n", a);
 		procmsg_msginfo_add_avatar(acd->msginfo, AVATAR_LIBRAVATAR, a);
+		g_free(a);
 	}
 
 	return FALSE; /* keep getting */
@@ -159,7 +160,13 @@ static GtkWidget *image_widget_from_url(const gchar *url, const gchar *md5)
 	}
 	curl_easy_setopt(curl, CURLOPT_URL, url);
 	curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, write_image_data_cb);
-	curl_easy_setopt(curl, CURLOPT_TIMEOUT, prefs_common_get_prefs()->io_timeout_secs);
+	/* make sure timeout is less than general IO timeout */
+	curl_easy_setopt(curl, CURLOPT_TIMEOUT,
+			(libravatarprefs.timeout == 0
+				|| libravatarprefs.timeout
+					> prefs_common_get_prefs()->io_timeout_secs)
+			? prefs_common_get_prefs()->io_timeout_secs
+			: libravatarprefs.timeout);
 	curl_easy_setopt(curl, CURLOPT_NOSIGNAL, 1);
 
 	filename = cache_name_for_md5(md5);
@@ -193,7 +200,7 @@ static GtkWidget *image_widget_from_url(const gchar *url, const gchar *md5)
 		if (filesize == 0)
 			missing_add_md5(libravatarmisses, md5);
 	} else {
-		g_warning("could not open '%s' for writting\n", filename);
+		g_warning("could not open '%s' for writing\n", filename);
 	}
 	curl_easy_cleanup(curl);
 	g_free(filename);
