@@ -1708,7 +1708,7 @@ static int perl_init(void)
 "     qw(forwarded locked colorlabel match matchcase),\n"
 "     qw(regexp regexpcase test),\n"
 "     qw(to cc subject from to_or_cc newsgroups inreplyto),\n"
-"     qw(references body_part headers_part message),\n"
+"     qw(references body_part headers_part headers_cont message),\n"
 "     qw(size_greater size_smaller size_equal),\n"
 "     qw(score_greater score_lower score_equal),\n"
 "     qw(age_greater age_lower partial tagged $permanent));\n"
@@ -1737,6 +1737,7 @@ static int perl_init(void)
 "sub references   { return \"references\";    }\n"
 "sub body_part    { return \"body_part\";     }\n"
 "sub headers_part { return \"headers_part\";  }\n"
+"sub headers_cont { return \"headers_cont\";  }\n"
 "sub message      { return \"message\";       }\n"
 "# access the mail directly\n"
 "sub header {\n"
@@ -1994,6 +1995,16 @@ static int perl_init(void)
 "      return ($myheader =~ m/$what/) unless $nocase;\n"
 "      return ($myheader =~ m/$what/i);\n"
 "    }\n"
+"  } elsif($where eq \"headers_cont\") {\n"
+"    (my $myheader = header_as_string_()) =~ s{^\\S+:\\s*}{};\n"
+"    if(not $regexp) {\n"
+"      $myheader =~ s/\\s+/ /g;\n"
+"      return (index($myheader,$what) != -1) unless $nocase;\n"
+"      return (index(lc2_($myheader),lc2_($what)) != -1);\n"
+"    } else {\n"
+"      return ($myheader =~ m/$what/) unless $nocase;\n"
+"      return ($myheader =~ m/$what/i);\n"
+"    }\n"
 "  } elsif($where eq \"message\") {\n"
 "    my $message = header_as_string_();\n"
 "    $message .= \"\\n\".body();\n"
